#
# spec file for package perl-Mozilla-CA
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define cpan_name Mozilla-CA
Name:           perl-Mozilla-CA
Version:        20250602.0.0
Release:        1.1
# 20250602 -> normalize -> 20250602.0.0
%define cpan_version 20250602
#Upstream: SUSE-Public-Domain
License:        GPL-2.0-or-later OR MPL-1.1 OR LGPL-2.1-or-later
Summary:        Mozilla's CA cert bundle in PEM format
URL:            https://metacpan.org/release/%{cpan_name}
Source0:        https://cpan.metacpan.org/authors/id/L/LW/LWP/%{cpan_name}-%{cpan_version}.tar.gz
Source1:        cpanspec.yml
# PATCH-FIX-OPENSUSE https://bugzilla.suse.com/show_bug.cgi?id=1228762
Patch0:         Mozilla-CA-20240730-Redirect-to-ca-certificates-bundle.patch
BuildArch:      noarch
BuildRequires:  perl
BuildRequires:  perl-macros
BuildRequires:  perl(Test::More) >= 0.94
Provides:       perl(Mozilla::CA) = %{version}
%undefine       __perllib_provides
%{perl_requires}
# MANUAL BEGIN
BuildRequires:  ca-certificates-mozilla
Requires:       ca-certificates-mozilla
# MANUAL END

%description
Mozilla::CA provides a copy of Mozilla's bundle of Certificate Authority
certificates in a form that can be consumed by modules and libraries based
on OpenSSL.

The module provide a single function:

* SSL_ca_file()

Returns the absolute path to the Mozilla's CA cert bundle PEM file.

%prep
%autosetup -n %{cpan_name}-%{cpan_version} -p1

find . -type f ! -path "*/t/*" ! -name "*.pl" ! -path "*/bin/*" ! -path "*/script/*" ! -path "*/scripts/*" ! -name "configure" -print0 | xargs -0 chmod 644

%build
perl Makefile.PL INSTALLDIRS=vendor
%make_build

%check
make test

%install
%perl_make_install
%perl_process_packlist
%perl_gen_filelist

%files -f %{name}.files
%doc Changes README

%changelog
* Tue Jun  3 2025 Tina Müller <tina.mueller@suse.com>
- Update Mozilla-CA-20240730-Redirect-to-ca-certificates-bundle.patch
* Tue Jun  3 2025 Tina Müller <timueller+perl@suse.de>
- updated to 20250602.0.0 (20250602)
  see /usr/share/doc/packages/perl-Mozilla-CA/Changes
  20250602
  - Update from Mozilla repository to 2025-06-02
  - Added certificates:
  - D-TRUST BR Root CA 2 2023
    sha256: 0552e6f83fdf65e8fa9670e666df28a4e21340b510cbe52566f97c4fb94b2bd1
  - D-TRUST EV Root CA 2 2023
    sha256: 8e8221b2e7d4007836a1672f0dcc299c33bc07d316f132fa1a206d587150f1ce
  - Removed certificates:
  - Baltimore CyberTrust Root
    sha256: 16af57a9f676b0ab126095aa5ebadef22ab31119d644ac95cd4b93dbf3f26aeb
  - Comodo AAA Services root
    sha256: d7a7a0fb5d7e2731d771e9484ebcdef71d5f0c3e0a2948782bc83ee0ea699ef4
  - Entrust.net Premium 2048 Secure Server CA
    sha256: 6dc47172e01cbcb0bf62580d895fe2b8ac9ad4f873801e0c10b9c837d21eb177
  - GlobalSign Root CA
    sha256: ebd41040e4bb3ec742c9e381d31ef2a41a48b6685c96e7cef3c1df6cd4331c99
  - Go Daddy Class 2 CA
    sha256: c3846bf24b9e93ca64274c0ec67c1ecc5e024ffcacd2d74019350e81fe546ae4
  - Starfield Class 2 CA
    sha256: 1465fa205397b876faa6f0a9958e5590e40fcc7faa4fb7c2c8677521fb5fb658
  - SwissSign Silver CA - G2
    sha256: be6c4da2bbb9ba59b6f3939768374246c3c005993fa98f020d1dedbed48a81d5
  - XRamp Global CA Root
    sha256: cecddc905099d8dadfc5b1d209b737cbe2c18cfb2c10c0ff0bcf0d3286fc1aa2
* Mon Feb 10 2025 Tina Müller <tina.mueller@suse.com>
- Update Mozilla-CA-20240730-Redirect-to-ca-certificates-bundle.patch
* Mon Feb  3 2025 Tina Müller <timueller+perl@suse.de>
- updated to 20250202.0.0 (20250202)
  see /usr/share/doc/packages/perl-Mozilla-CA/Changes
  20250202
  - Update from Mozilla repository to 2025-02-02
  - Added certificates:
  - GLOBALTRUST 2020
    sha256: 9a296a5182d1d451a2e37f439b74daafa267523329f90f9a0d2007c334e23c9a
  - Removed certificates:
  - Entrust Root Certification Authority - G4
    sha256: db3517d1f6732a2d5ab97c533ec70779ee3270a62fb4ac4238372460e6f01e88
  - SecureSign RootCA11
    sha256: bf0feefb9e3a581ad5f9e9db7589985743d261085c4d314f6f5d7259aa421612
  - Security Communication RootCA3
    sha256: 24a55c2ab051442d0617766541239a4ad032d7c55175aa34ffde2fbc4f5c5294
* Tue Dec 31 2024 Tina Müller <tina.mueller@suse.com>
- Update Mozilla-CA-20240730-Redirect-to-ca-certificates-bundle.patch
* Tue Sep 24 2024 Tina Müller <timueller+perl@suse.de>
- updated to 20240924.0.0 (20240924)
  see /usr/share/doc/packages/perl-Mozilla-CA/Changes
  20240924
  - Update from Mozilla repository to 2024-09-24
  - Added certificates:
  - SecureSign Root CA12
    sha256: 3f034bb5704d44b2d08545a02057de93ebf3905fce721acbc730c06ddaee904e
  - SecureSign Root CA14
    sha256: 4b009c1034494f9ab56bba3ba1d62731fc4d20d8955adcec10a925607261e338
  - SecureSign Root CA15
    sha256: e778f0f095fe843729cd1a0082179e5314a9c291442805e1fb1d8fb6b8886c3a
  - TWCA CYBER Root CA
    sha256: 3f63bb2814be174ec8b6439cf08d6d56f0b7c405883a5648a334424d6b3ec558
* Mon Sep  2 2024 Tina Müller <tina.mueller@suse.com>
- Add ca-certificates-mozilla to runtime Requires as well
  boo#1228762
* Mon Aug 26 2024 Tina Müller <tina.mueller@suse.com>
- Add Mozilla-CA-20240730-Redirect-to-ca-certificates-bundle.patch,
  https://bugzilla.suse.com/show_bug.cgi?id=1228762
  boo#1228762
* Wed Jul 31 2024 Tina Müller <timueller+perl@suse.de>
- updated to 20240730.0.0 (20240730)
  see /usr/share/doc/packages/perl-Mozilla-CA/Changes
  20240730
  - Update from Mozilla repository to 2024-07-30
  - Added certificates:
  - FIRMAPROFESIONAL CA ROOT-A WEB
    sha256: bef256daf26e9c69bdec1602359798f3caf71821a03e018257c53c65617f3d4a
  - Removed certificates:
  - GLOBALTRUST 2020
    sha256: 9a296a5182d1d451a2e37f439b74daafa267523329f90f9a0d2007c334e23c9a
* Fri Mar 22 2024 Tina Müller <timueller+perl@suse.de>
- updated to 20240313
  see /usr/share/doc/packages/perl-Mozilla-CA/Changes
  20240313
  - Update from Mozilla repository to 2024-03-13
  - Added certificates:
  - Telekom Security TLS ECC Root 2020
    sha256: 578af4ded0853f4e5998db4aeaf9cbea8d945f60b620a38d1a3c13b2bc7ba8e1
  - Telekom Security TLS RSA Root 2023
    sha256: efc65cadbb59adb6efe84da22311b35624b71b3b1ea0da8b6655174ec8978646
* Fri Mar  8 2024 Tina Müller <tina.mueller@suse.com>
- Fix disabling of __perllib_provides
* Thu Dec 14 2023 Tina Müller <timueller+perl@suse.de>
- updated to 20231213
  see /usr/share/doc/packages/perl-Mozilla-CA/Changes
  20231213
  - Update from Mozilla repository to 2023-12-13
  - Added certificates:
  - CommScope Public Trust ECC Root-01
    sha256: 11437cda7bb45e41365f45b39a38986b0de00def348e0c7bb0873633800bc38b
  - CommScope Public Trust ECC Root-02
    sha256: 2ffb7f813bbbb3c89ab4e8162d0f16d71509a830cc9d73c262e5140875d1ad4a
  - CommScope Public Trust RSA Root-01
    sha256: 02bdf96e2a45dd9bf18fc7e1dbdf21a0379ba3c9c2610344cfd8d606fec1ed81
  - CommScope Public Trust RSA Root-02
    sha256: ffe943d793424b4f7c440c1c3d648d5363f34b82dc87aa7a9f118fc5dee101f1
  - TrustAsia Global Root CA G3
    sha256: e0d3226aeb1163c2e48ff9be3b50b4c6431be7bb1eacc5c36b5d5ec509039a08
  - TrustAsia Global Root CA G4
    sha256: be4b56cb5056c0136a526df444508daa36a0b54f42e4ac38f72af470e479654c
  - Removed certificates:
  - Security Communication Root CA
    sha256: e75e72ed9f560eec6eb4800073a43fc3ad19195a392282017895974a99026b6c
* Tue Aug 22 2023 Tina Müller <timueller+perl@suse.de>
- updated to 20230821
  see /usr/share/doc/packages/perl-Mozilla-CA/Changes
  20230821
  - Update from Mozilla repository to 2023-08-21
  - Added certificates:
  - Atos TrustedRoot Root CA ECC TLS 2021
    sha256: b2fae53e14ccd7ab9212064701ae279c1d8988facb775fa8a008914e663988a8
  - Atos TrustedRoot Root CA RSA TLS 2021
    sha256: 81a9088ea59fb364c548a6f85559099b6f0405efbf18e5324ec9f457ba00112f
  - SSL.com TLS ECC Root CA 2022
    sha256: c32ffd9f46f936d16c3673990959434b9ad60aafbb9e7cf33654f144cc1ba143
  - SSL.com TLS RSA Root CA 2022
    sha256: 8faf7d2e2cb4709bb8e0b33666bf75a5dd45b5de480f8ea8d4bfe6bebc17f2ed
  - Sectigo Public Server Authentication Root E46
    sha256: c90f26f0fb1b4018b22227519b5ca2b53e2ca5b3be5cf18efe1bef47380c5383
  - Sectigo Public Server Authentication Root R46
    sha256: 7bb647a62aeeac88bf257aa522d01ffea395e0ab45c73f93f65654ec38f25a06
  - Removed certificates:
  - E-Tugra Global Root CA ECC v3
    sha256: 873f4685fa7f563625252e6d36bcd7f16fc24951f264e47e1b954f4908cdca13
  - E-Tugra Global Root CA RSA v3
    sha256: ef66b0b10a3cdb9f2e3648c76bd2af18ead2bfe6f117655e28c4060da1a3f4c2
* Tue Aug  8 2023 Tina Müller <timueller+perl@suse.de>
- updated to 20230807
  see /usr/share/doc/packages/perl-Mozilla-CA/Changes
  20230807
  - Prevent extra headers in tarball and make it reproducible
  20230801
  - Update from Mozilla repository to 2023-08-01
  - Added certificates:
  - BJCA Global Root CA1
    sha256: f3896f88fe7c0a882766a7fa6ad2749fb57a7f3e98fb769c1fa7b09c2c44d5ae
  - BJCA Global Root CA2
    sha256: 574df6931e278039667b720afdc1600fc27eb66dd3092979fb73856487212882
  - Removed certificates:
  - E-Tugra Certification Authority
    sha256: b0bfd52bb0d7d9bd92bf5d4dc13da255c02c542f378365ea893911f55e55f23c
  - Hongkong Post Root CA 1
    sha256: f9e67d336c51002ac054c632022d66dda2e7e3fff10ad061ed31d8bbb410cfb2
  - Network Solutions Certificate Authority
    sha256: 15f0ba00a3ac7af3ac884c072b1011a077bd77c097f40164b2f8598abd83860c
  - Staat der Nederlanden EV Root CA
    sha256: 4d2491414cfe956746ec4cefa6cf6f72e28a1329432f9d8a907ac4cb5dadc15a
  - TrustCor ECA-1
    sha256: 5a885db19c01d912c5759388938cafbbdf031ab2d48e91ee15589b42971d039c
  - TrustCor RootCert CA-1
    sha256: d40e9c86cd8fe468c1776959f49ea774fa548684b6c406f3909261f4dce2575c
  - TrustCor RootCert CA-2
    sha256: 0753e940378c1bd5e3836e395daea5cb839e5046f1bd0eae1951cf10fec7c965
* Wed Nov 23 2022 Tina Müller <tina.mueller@suse.com>
- Remove modifying of mk-ca-bundle.pl and update-cacert-file (not present
  in distribution anymore)
* Tue Nov 15 2022 Tina Müller <timueller+perl@suse.de>
- updated to 20221114
  see /usr/share/doc/packages/perl-Mozilla-CA/Changes
  Revision history for Mozilla-CA
  20221114
  - Update from Mozilla repository to 2022-11-07
  - stop installing mk-ca-bundle.pl script
  - moved repository and issues to https://github.com/libwww-perl/Mozilla-CA
  - switched tests from Test to Test::More
  - fix license specification in metadata
* Sat Oct  2 2021 Tina Müller <timueller+perl@suse.de>
- updated to 20211001
  see /usr/share/doc/packages/perl-Mozilla-CA/Changes
  20211001
  - Update mk-ca-bundle.pl and Mozilla data to 2021-10-01 (Aaron Rowe)
  - Improve metadata for license information (Shoichi Kaji)
  20200520
  - Update from Mozilla repository to 2020-05-20
  - Update bundled mk-ca-bundle.pl from upstream.
* Thu May 21 2020 Tina Müller <timueller+perl@suse.de>
  updated to 20200520
  see /usr/share/doc/packages/perl-Mozilla-CA/Changes
  20200520
  - Update from Mozilla repository to 2020-05-20
  - Update bundled mk-ca-bundle.pl from upstream.
* Fri Mar  2 2018 coolo@suse.com
- updated to 20180117
  see /usr/share/doc/packages/perl-Mozilla-CA/Changes
  20180301
  - Update from Mozilla repository to 2018-01-17
  - Update bundled mk-ca-bundle.pl from upstream.
  20160104
  - Update from Mozilla repository
* Wed Jan  6 2016 coolo@suse.com
- updated to 20160104
  see /usr/share/doc/packages/perl-Mozilla-CA/Changes
* Thu Aug 27 2015 coolo@suse.com
- updated to 20150826
  see /usr/share/doc/packages/perl-Mozilla-CA/Changes
  20150826
  - Update from Mozilla repository
  - Update license to match license of data source (MPL 2)
  20141217
  - Update from Mozilla repository
* Sun Apr 19 2015 coolo@suse.com
- updated to 20141217
  see /usr/share/doc/packages/perl-Mozilla-CA/Changes
* Wed Apr  9 2014 lars@linux-schulserver.de
- update to 20130114:
  + New certificate: "T-TeleSec GlobalRoot Class 3"
  + Fix test (RT#79129, reported by Sinan Unur)
  + Add mk-ca-bundle.pl from git repository to distribution.
  + Add new/additional certificates from the following CAs: Verisign,
    UTN-USER, UTN USERFirst, Sonera, NetLock Qualified, SwissSign
    Platinum, S-TRUST, ComSign, Actalis, Trustis, StartCom, Buypass.
  + Download the certdata from mozilla over SSL (John Joseph Bachir)
  + CA updates:
    Removes:
  - Hellenic Academic and Research Institutions RootCA 2011
- move mk-ca-bundle.pl to bindir
- fix path names in update-cacert-file
* Tue Feb 21 2012 coolo@suse.com
- initial package 20120118
  * created by cpanspec 1.78.06
